// **********************************************************************
//
// Copyright (c) 2008-2023 VCI-Tech, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described the
// ICE_LICENSE file included this distribution.
//
// **********************************************************************

#pragma once

#include "01-common.ice"

[["java:package:com.vci.corba"]]
["cs:namespace:com.vci.corba"]

// module com {
// module vci {
// module corba {
module portal{
	module data {
		struct PortalVI{
			string id;
			short typeFlag;
			string typeName;
			string viName;
			short viType;
			string prm;
		};
		sequence<PortalVI> PortalVIArray;
		struct PLAction{
			string plOId;
			string plCode;
			string plName;
			string plBSUrl;
			string plCSClass;
			string plDesc;
			string plTypeType;
			long plCreateTime;
			string plCreateUser;
			long plModifyTime;
			string plModifyUser;
			string plLicensOrs;
			string plActionCls;
		};
		sequence<PLAction> PLActionArray;
		struct PLTypeAction{
			string plOId;
			string typeName;
			string actionoId;
		};
		sequence<PLTypeAction> PLTypeActionArray;			
		struct PLActionCls{
			string id;
			string name;
			string pid;
			string description;
			string creator;
			long createTime;
			short serialno;
		};
		sequence<PLActionCls> PLActionClsArray;
		struct PLActionParam{
			string oid;
			string name;
			string defaultValue;
			string description;
			string action;
		};
		sequence<PLActionParam> PLActionParamArray;
		struct PLCommandParameter{
			string plOId;
			string plCommandOId;
			string plKey;
			string plValue;
			long plCreateTime;
			string plCreateUser;
			long plModifyTime;
			string plModifyUser;
			string plLicensOrs;
		};
		sequence<PLCommandParameter> PLCommandParameterArray;
		struct PLUILayout{
			string plOId;
			string plCode;
			string plName;
			string plRelatedType;
			string plStyle;
			string plDesc;
			short plIsShowTab;
			short plIsShowForm;
			short plIsShowNavigator;
			long plCreateTime;
			string plCreateUser;
			long plModifyTime;
			string plModifyUser;
			string plLicensOrs;
		};
		sequence<PLUILayout> PLUILayoutArray;
		struct PLTabButton{
			string plOId;
			string plTableOId;
			string plPageOId;
			string plActionOId;
			string plLabel;
			string plAreaType;
			string plDesc;
			short plSeq;
			long plCreateTime;
			string plCreateUser;
			long plModifyTime;
			string plModifyUser;
			string plLicensOrs;
			//add by sonyf 2015.0.08增加 分组、显示方式、图标、是否需要授权
			string plParentOid;
			string displayMode;
			string iconPath;
			string authorization;
			//add by caill
			string show;
			//end
		};
		sequence<PLTabButton> PLTabButtonArray;
		struct PLTabPage{
			string plOId;
			string plCode;
			string plName;
			short plIsOpen;
			string plLabel;
			string plDesc;
			short plSeq;
			string plContextOId;
			short plAreaType;
			long plCreateTime;
			string plCreateUser;
			long plModifyTime;
			string plModifyUser;
			string plLicensOrs;
			string plOpenExpression;
			// UI解析器，用分号;分隔各组值，即:java_cs、java_bs、net_cs、net_bs、mobile_cs、mobile_bs
			// 值格式示例：java_cs:xxx;java_bs:xxx;net_cs:xxx;net_bs:xxx;mobile_cs:xx;mobile_bs:xxx;
			string plUIParser; 	
			// 扩展属性，用分号;分隔各组值，每组用冒号:分隔扩展属性名称与扩展属性值，可以定义任意组，数据库层面该字段最大长度4000
			// 值格式示例：ext1:xx;ext2;ext3:xx;ext4:xxx;extn:xxx;
			string plExtAttr;	
		};
		sequence<PLTabPage> PLTabPageArray;
		struct PLPageDefination{
			string plOId;
			string plTabPageOId;
			short plType;
			string name;
			string desc;
			short seq;
			string plDefination;
		};
		sequence<PLPageDefination> PLPageDefinationArray;
		
		
		struct Constraint{
			string key;
			string value;
		};
		sequence<Constraint> ConstraintArray;
	};

	interface PortalService{
		void test();
	
		//保存视图
		bool savePortalVI(data::PortalVI pvi)throws common::VCIError;
		//更新视图
		bool updatePortalVI(data::PortalVI pvi)throws common::VCIError;
		//删除视图
		bool deletePortalVI(data::PortalVI pvi)throws common::VCIError;
		//根据ID删除视图
		bool deletePortalVIByID(string id)throws common::VCIError;
		//获取指定类型下的所有视图
		data::PortalVIArray getPortalVIArrayByTypeName(string typeName)throws common::VCIError;
		//获取指定类型下的所有视图,分页
		//data::PortalVIArray getPagePortalVIArrayByTypeName(string typeName, long startPage, long endPage)throws common::VCIError;
		//获取指定类型下的所有视图根据条件
		//data::PortalVIArray getPagePortalVIArrayByCondition(string typeName, short sheetType, string sheetName, long startPage, long endPage)throws common::VCIError;
		// 返回表单根据翻页信息
		data::PortalVIArray getPagePortalVIArrayByPageInfo(
			string typeName, string viName, short viType, short viTypeFlag,					
			long pageIndex, long pageSize, out long total)throws common::VCIError;
		// 级联删除表单
		bool deletePagePortalVIForCascade(common::data::StringArray oids) throws common::VCIError;
		//获取指定类型下的所有视图的数量
		long getPortalVICountByTypeName(string typeName)throws common::VCIError;
		//获取指定类型下的所有视图的数量
		long getPortalVICountByCondition(string typeName, short sheetType, string sheetName)throws common::VCIError;
		//获取指定ID的视图
		data::PortalVI getPortalVIById(string id)throws common::VCIError;
		//获取指定ID的视图
		data::PortalVI getPortalVIBySymbol(string viName)throws common::VCIError;
		//获取所有结果集，缓存使用
		data::PortalVIArray getAllPortalVI()throws common::VCIError;
		//获取指定英文名称和业务类型模糊查询对应的表单
		data::PortalVIArray getPortalVIBySymbolAndTypeName(string viName, string type)throws common::VCIError;
		//保存对象
		bool savePLAction(data::PLAction action)throws common::VCIError;
		//更新对象
		bool updatePLAction(data::PLAction action)throws common::VCIError;
		//删除对象
		bool deletePLAction(data::PLAction action)throws common::VCIError;
		//根据ID删除对象
		bool deletePLActionByID(string id)throws common::VCIError;
		
		//保存对象
		bool savePLCommandParameter(data::PLCommandParameter cmdParameter)throws common::VCIError;
		//更新对象
		bool updatePLCommandParameter(data::PLCommandParameter cmdParameter)throws common::VCIError;
		//删除对象
		bool deletePLCommandParameter(data::PLCommandParameter cmdParameter)throws common::VCIError;
		//根据ID删除对象
		bool deletePLCommandParameterByID(string id)throws common::VCIError;
		//add by songyf 2015.02.10 根据TabButtonID删除参数信息
		bool deletePLCommandParameterByTabButtonId(string id)throws common::VCIError;
		//end by songyf 2015.02.10
		
		//保存对象
		bool savePLUILayout(data::PLUILayout layoutDefination)throws common::VCIError;
		//更新对象
		bool updatePLUILayout(data::PLUILayout layoutDefination)throws common::VCIError;
		//删除对象
		bool deletePLUILayout(data::PLUILayout layoutDefination)throws common::VCIError;
		//根据ID删除对象
		bool deletePLUILayoutByID(string id)throws common::VCIError;
		// 根据OID删除对象（级联）
		bool deletePLUILayoutByOidsForCascade(common::data::StringArray oids) throws common::VCIError;
		
		//保存对象
		bool savePLTabButton(data::PLTabButton tabButton)throws common::VCIError;
		// 保存按钮(保存按钮及其参数)
		bool savePLTabButtonAndParams(data::PLTabButtonArray tabButtons, data::PLCommandParameterArray btnParams)throws common::VCIError;
		//更新对象
		bool updatePLTabButton(data::PLTabButton tabButton)throws common::VCIError;
		//删除对象
		bool deletePLTabButton(data::PLTabButton tabButton)throws common::VCIError;
		//根据ID删除对象
		bool deletePLTabButtonByID(string id)throws common::VCIError;
		// 根据OID删除对象（级联）
		bool deletePLTabButtonByOidsForCascade(common::data::StringArray oids) throws common::VCIError;
		
		//保存对象
		bool savePLTabPage(data::PLTabPage tabPage)throws common::VCIError;
		//更新对象
		bool updatePLTabPage(data::PLTabPage tabPage)throws common::VCIError;
		//删除对象
		bool deletePLTabPage(data::PLTabPage tabPage)throws common::VCIError;
		//根据ID删除对象
		bool deletePLTabPageByID(string id)throws common::VCIError;
		// 根据OID删除对象（级联）
		bool deletePLTabPageByOidsForCascade(common::data::StringArray oids) throws common::VCIError;
		
		//保存对象
		bool savePLPageDefination(data::PLPageDefination pageDef)throws common::VCIError;
		//更新对象
		bool updatePLPageDefination(data::PLPageDefination pageDef)throws common::VCIError;
		//删除对象
		bool deletePLPageDefination(data::PLPageDefination pageDef)throws common::VCIError;
		//根据ID删除对象
		bool deletePLPageDefinationByID(string id)throws common::VCIError;
		// 根据OID删除对象（级联）
		bool deletePLPageDefinationByOidsForCascade(common::data::StringArray oids) throws common::VCIError;
		
		//根据ID获取指定的PLAction
		data::PLAction getPLActionById(string plOId)throws common::VCIError;
		//获取所有PLAction
		data::PLActionArray getAllPLAction()throws common::VCIError;
		//根据约束条件组查询数组, 查询PLActions
		data::PLActionArray getPLActionsByConsArray(data::ConstraintArray consArray)throws common::VCIError;
		//查询所有按钮分类
		data::PLActionClsArray getPLActionClsArray()throws common::VCIError;
		//add by songyf 2015.02.09 增加按钮分类，按钮参数配置 等接口
		//创建分类
		string creaetePLActionCls(data::PLActionCls cls);
		//修改分类
		string editPLActionCls(data::PLActionCls cls);
		//删除分类
		string deletePLActionClsById(string id);
		//查询Action按钮参数
		data::PLActionParamArray getPLActionParamArrayByActionId(string actionId)throws common::VCIError;
		//创建按钮参数
		string createPLActionParam(data::PLActionParam param);
		//批量创建按钮参数
		string createPLActionParamBatch(data::PLActionParamArray params);
		//修改按钮参数信息
		string editPLActionParam(data::PLActionParam param);
		//删除按钮参数
		string deletePLActionParam(string id);
		//end by songyf 2015.02.09
		bool savePLTypeActionEntity(data::PLTypeAction typeAction) throws common::VCIError;
		bool deletePLTypeActionEntityByTypeAndAction(string type, string actionoId) throws common::VCIError;
		data::PLActionArray getAllPLActionEntityByType(string type) throws common::VCIError;
		//根据ID获取指定的PLCommandParameter
		data::PLCommandParameter getPLCommandParameterById(string plOId)throws common::VCIError;
		//根据plCommandOId获取PLCommandParameterArray
		data::PLCommandParameterArray getPLCommandParametersByCommandOId(string plCommandOId)throws common::VCIError;
		//获取全量结果集，缓存使用
		data::PLCommandParameterArray getAllPLCommandParameters()throws common::VCIError;
		//根据ID获取指定的PLUILayout
		data::PLUILayout getPLUILayoutById(string plOId)throws common::VCIError;
		//根据模糊查询获取PLUILayoutArray
		data::PLUILayoutArray getPLUILayoutEntity(string contentStr)throws common::VCIError;
		//根据关联类型获取PLUILayoutArray
		data::PLUILayoutArray getPLUILayoutsByRelatedType(string plRelatedType)throws common::VCIError;
		//根据关联判刑获取PLUILayoutArray
		data::PLUILayoutArray getPLUILayoutsByRelatedTypeAndQueryInfo(
			string plRelatedType, string name, string code, 
			long pageIndex, long pageSize, out long total)throws common::VCIError;
		//根据关联类型和编号获取PLUILayoutArray
		data::PLUILayoutArray getPLUILayoutEntityByTypeAndCode(string plRelatedType, string code)throws common::VCIError;
		//获得全量的PLUILayoutArray
		data::PLUILayoutArray getAllPLUILayouts()throws common::VCIError;
		//根据ID获取指定的PLTabPage
		data::PLTabPage getPLTabPageById(string plOId)throws common::VCIError;
		//获取全量的pltabpage,缓存使用
		data::PLTabPageArray getAllPLTabPages()throws common::VCIError;
		//根据plPageDefinationOId获取PLUILayoutArray
		data::PLTabPageArray getPLTabPagesByPageDefinationOId(string plPageDefinationOId)throws common::VCIError;
		//根据contextId和区域类型，按顺序获取tab页
		data::PLTabPageArray getTabPagesByContextIdAndType(string contextId, short type) throws common::VCIError;
	
		//根据ID获取指定的PLTabButton
		data::PLTabButton getPLTabButtonById(string plOId)throws common::VCIError;
		//根据plTableOId获取PLTabButtonArray
		data::PLTabButtonArray getPLTabButtonsByTableOId(string plTableOId)throws common::VCIError;
		//获取全量的结果集，缓存使用
		data::PLTabButtonArray getAllPLTabButtons()throws common::VCIError;
		//根据ID获取指定的PLPageDefination
		data::PLPageDefination getPLPageDefinationById(string plOId)throws common::VCIError;
		//根据plPageContextOId获取指定的PLPageDefinationArray
		data::PLPageDefinationArray getPLPageDefinationsByPageContextOId(string plPageContextOId)throws common::VCIError;
		//获取所有的结果集，缓存使用
		data::PLPageDefinationArray getAllPLPageDefinations()throws common::VCIError;
		//获取所有组件定义集，不包含大字段信息
		data::PLPageDefinationArray getAllPLPageDefinationsWithNoConf()throws common::VCIError;
		//根据type,code获取指定的PLTabPageArray
		data::PLTabPageArray getPLTabPagesByTypeANDCode(string type, string code)throws common::VCIError;
		
		//根据类型名和视图名获取视图
		data::PortalVI getPortalVIByTypeNameAndVIName(string typeName, string viName)throws common::VCIError;
		//根据type和formName判断表单是否能被修改
		bool judgeUpdateButton(short type, string viName, string typeName)throws common::VCIError;
		//根据id判断表单是否能被删除
		bool judgeDeleteButton(string id, string typeName)throws common::VCIError;
		
		// 将页签复制到指定的上下文
		bool copyTabPageToPageLayout(common::data::StringArray tabPageOids, 
			data::PLUILayout layoutDefination, short areaType)
			throws common::VCIError;
			
		// 将组件复制到指定的页签
		bool copyComptToTabPage(common::data::StringArray comptOids, 
			data::PLTabPage tabPage)
			throws common::VCIError;
		
	};
}

// }}}